@@ -37,6 +37,8 @@ Component::Component( QString type, QString id )
     m_Vflip  = 1;
     m_color  = QColor( Qt::white );
 
+    //m_group = NULL;
+
     m_showId     = false;
     m_showVal    = false;
     m_moving     = false;
@@ -142,6 +144,7 @@ bool Component::setPropStr( QString prop, QString val )
             p->setValStr( vstr );
         }
     }
+    else if( prop =="ValLabelText" ) setValLabelText( val );
     else return CompBase::setPropStr( prop, val );
     return true;
 }
@@ -396,12 +399,6 @@ void Component::slotGroup()
 
 void Component::remove()
 {
-    if( m_propDialog )
-    {
-        m_propDialog->setParent( NULL );
-        m_propDialog->close();
-        delete m_propDialog;
-    }
     for( uint i=0; i<m_pin.size(); i++ )
         if( m_pin[i] ) m_pin[i]->removeConnector();
 
@@ -461,8 +458,9 @@ void Component::setflip()
 {
     setTransform( QTransform::fromScale( m_Hflip, m_Vflip ) );
     m_idLabel->setTransform( QTransform::fromScale( m_Hflip, m_Vflip ) );
+    m_idLabel->updtLabelPos();
     m_valLabel->setTransform( QTransform::fromScale( m_Hflip, m_Vflip ) );
-
+    m_valLabel->updtLabelPos();
     for( Pin* pin : m_signalPin ) pin->flip( m_Hflip, m_Vflip );
 
     if( !m_hidden ) moveSignal();    // Used by sockets
@@ -480,7 +478,7 @@ void Component::rotateAngle( double a )
 }
 
 QString Component::idLabel() { return m_idLabel->toPlainText(); }
-void Component::setIdLabel( QString id ) { m_idLabel->setPlainText( id ); }
+void Component::setIdLabel( QString id ) { m_idLabel->setPlainText( id ); m_idLabel->updtLabelPos(); }
 
 QPointF Component::getIdPos() { return m_idLabel->getLabelPos(); }
 void Component::setIdPos( QPointF p ) { m_idLabel->setLabelPos( p ); }
@@ -488,7 +486,7 @@ void Component::setIdPos( QPointF p ) { m_idLabel->setLabelPos( p ); }
 int Component::getIdRot() { return m_idLabel->getAngle(); }
 void Component::setIdRot( int r ) { m_idLabel->setAngle(r); }
 
-void Component::setLabelPos( int x, int y, int rot )
+void Component::setLabelPos( float x, float y, int rot )
 {
     m_idLabel->m_labelx = x;
     m_idLabel->m_labely = y;
@@ -506,7 +504,7 @@ void Component::setValPos( QPointF p ) { m_valLabel->setLabelPos( p ); }
 int Component::getValRot() { return m_valLabel->getAngle(); }
 void Component::setValRot( int r ) { m_valLabel->setAngle(r); }
 
-void Component::setValLabelPos( int x, int y, int rot )
+void Component::setValLabelPos( float x, float y, int rot )
 {
     m_valLabel->m_labelx = x;
     m_valLabel->m_labely = y;
@@ -516,7 +514,7 @@ void Component::setValLabelPos( int x, int y, int rot )
 
 void Component::updtValLabelPos() { m_valLabel->updtLabelPos(); }
 
-void Component::setValLabelText( QString t ) { m_valLabel->setPlainText( t ); }
+void Component::setValLabelText( QString t ) { m_valLabel->setPlainText( t ); m_valLabel->updtLabelPos(); }
 QString Component::getValLabelText() { return m_valLabel->toPlainText(); }
 
 QString Component::showProp()
