@@ -15,10 +15,10 @@ class LibraryItem;
 class MAINMODULE_EXPORT Potentiometer : public Dialed, public eElement
 {
     public:
-        Potentiometer( QObject* parent, QString type, QString id );
+        Potentiometer( QString type, QString id );
         ~Potentiometer();
 
- static Component* construct( QObject* parent, QString type, QString id );
+ static Component* construct( QString type, QString id );
  static LibraryItem* libraryItem();
 
         virtual void stamp() override;
