@@ -10,42 +10,30 @@
 
 class InoDebugger : public AvrGccDebugger
 {
-    Q_OBJECT
-    Q_PROPERTY( board_t Board        READ board       WRITE setBoard       DESIGNABLE true USER true )
-    Q_PROPERTY( QString Custom_Board READ customBoard WRITE setCustomBoard DESIGNABLE true USER true )
+    //Q_OBJECT
+
     public:
         InoDebugger( CodeEditor* parent, OutPanelText* outPane );
         ~InoDebugger();
         
-        enum board_t {
-            Uno = 0,
-            Mega,
-            Nano,
-            Duemilanove,
-            Leonardo,
-            Custom
-        };
-        Q_ENUM( board_t )
-        
+        QString getBoard() { return m_board; }
+        void setBoard( QString board );
+
         QString customBoard() { return m_customBoard; }
         void setCustomBoard( QString b ){ m_customBoard = b; }
-        
-        board_t board() { return m_Ardboard; }
-        void setBoard( board_t b ){ m_Ardboard = b; }
 
-        virtual QString toolPath() { return m_arduinoPath; }
+        virtual QString toolPath() override { return m_arduinoPath; }
         virtual void setToolPath( QString path ) override;
 
         virtual bool upload() override;
         virtual int  compile( bool debug ) override;
 
+        virtual PropDialog* compilerProps() override;
+
     protected:
         virtual bool postProcess() override;
         
     private:
-        QString getBoard();
-        virtual void setBoardName( QString board ) override;
-
         int m_version;
         int m_lastInoLine;
         int m_loopInoLine;
@@ -54,8 +42,7 @@ class InoDebugger : public AvrGccDebugger
         QString m_builder;
         QString m_sketchBook;
         QString m_customBoard;
-        board_t m_Ardboard;
-        QStringList m_ArdboardList;
+        QString m_board;
 };
 
 #endif
